        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 22 <br>3,5,7,8,9,12,14,20,21,24,27,28,29,31,33,36,39,40,41,46,47,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 16 <br>1,2,4,11,13,16,17,18,19,30,34,37,38,42,43,45';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,6,10,15,22,23,25,26,32,35,44,48,49';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 22 <br>3,5,7,8,9,12,14,20,21,24,27,28,29,31,33,36,39,40,41,46,47,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 16 <br>1,2,4,11,13,16,17,18,19,30,34,37,38,42,43,45';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,6,10,15,22,23,25,26,32,35,44,48,49';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 22 <br>3,5,7,8,9,12,14,20,21,24,27,28,29,31,33,36,39,40,41,46,47,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 16 <br>1,2,4,11,13,16,17,18,19,30,34,37,38,42,43,45';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,6,10,15,22,23,25,26,32,35,44,48,49';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 22 <br>3,5,7,8,9,12,14,20,21,24,27,28,29,31,33,36,39,40,41,46,47,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 16 <br>1,2,4,11,13,16,17,18,19,30,34,37,38,42,43,45';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,6,10,15,22,23,25,26,32,35,44,48,49';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 22 <br>3,5,7,8,9,12,14,20,21,24,27,28,29,31,33,36,39,40,41,46,47,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 16 <br>1,2,4,11,13,16,17,18,19,30,34,37,38,42,43,45';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,6,10,15,22,23,25,26,32,35,44,48,49';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 22 <br>3,5,7,8,9,12,14,20,21,24,27,28,29,31,33,36,39,40,41,46,47,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 16 <br>1,2,4,11,13,16,17,18,19,30,34,37,38,42,43,45';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260818 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,6,10,15,22,23,25,26,32,35,44,48,49';}
}
